## Changelog

### Release 1.0.0b1 (2023-04-20)

We've dropped support for python < 3.7.
We now test under both Lektor 3.3.x and (now in pre-release) Lektor 3.4.x 

### Version 0.1a1 (2021-02-13)

Split code into it's own git respository.

